<?php

	use UmiCms\Service;
	use Initpro\KassaSdk\Payment;
	use Initpro\KassaSdk\Check;
	use Initpro\KassaSdk\Vat;
	use Initpro\KassaSdk\Position;
	use Initpro\KassaSdk\Client;
	use Initpro\KassaSdk\GroupManager;

	/** Класс обработчиков событий */
	class Initpro_kassaHandlers {
		/** @var appointment $module */
		public $module;
		private $tranz_config;

		public function onSystemModifyPropertyValue(iUmiEventPoint $event) {

			$this->tranz_config = json_decode(file_get_contents('transaction_config.json'), true);

			if ($event->getParam('property') != 'payment_status_id') {
				return false;
			}

			if ($event->getMode() != 'after') {
				return false;
			}

			if ($event->getParam('oldValue') == $event->getParam('newValue')) {
				return false;
			}

			if (!in_array($event->getParam('newValue'), Array($this->tranz_config['object-prinyata'], $this->tranz_config['object-otklonena']))) {
				return false;
			}

			$entity = $event->getRef('entity');
			$objectsCollection = umiObjectsCollection::getInstance();
			$order = order::get($entity->getId());

			$this->fiscalize($order, $event->getParam('newValue'));

			return true;
		}


		public function onPaymentStatusChanged(iUmiEventPoint $event) {

			$this->tranz_config = json_decode(file_get_contents('transaction_config.json'), true);

			if ($event->getMode() != 'after') {
				return false;
			}

			if ($event->getParam('old-status-id') == $event->getParam('new-status-id')) {
				return false;
			}

			if (!in_array($event->getParam('new-status-id'), Array($this->tranz_config['object-prinyata'], $this->tranz_config['object-otklonena']))) {
				return false;
			}

			$order = $event->getRef('order');

			$this->fiscalize($order, $event->getParam('new-status-id'));

			return true;
		}

		private function fiscalize($order, $paymentStatus) {
			include "standalone.php";
			$umiRegistry = Service::Registry();

			$vatId = $umiRegistry->get('//modules/initpro_kassa/vat');
			$sql = "SELECT varchar_val FROM cms3_object_content WHERE obj_id = ".$vatId;
			$connection = ConnectionPool::getInstance()->getConnection();
			$result = $connection->queryResult($sql);
			$singleRow = $result->fetch();
			$vat = $singleRow['varchar_val'];

			$snoId = $umiRegistry->get('//modules/initpro_kassa/sno');
			$sql = "SELECT varchar_val FROM cms3_object_content WHERE obj_id = ".$snoId;
			$connection = ConnectionPool::getInstance()->getConnection();
			$result = $connection->queryResult($sql);
			$singleRow = $result->fetch();
			$sno = intval($singleRow['varchar_val']);

			$host = $umiRegistry->get('//modules/initpro_kassa/host');
			$is_print_check = $umiRegistry->get('//modules/initpro_kassa/is_print_check');
			$queue_id = $umiRegistry->get('//modules/initpro_kassa/queue_id');
			$shop_id = $umiRegistry->get('//modules/initpro_kassa/shop_id');
			$secret = $umiRegistry->get('//modules/initpro_kassa/shop_secret');

			include_once  (__DIR__."/helpers/initpro-initpro-kassa-php-sdk/src/Payment.php");
			include_once  (__DIR__."/helpers/initpro-initpro-kassa-php-sdk/src/Check.php");
			include_once  (__DIR__."/helpers/initpro-initpro-kassa-php-sdk/src/Vat.php");
			include_once  (__DIR__."/helpers/initpro-initpro-kassa-php-sdk/src/Position.php");
			include_once  (__DIR__."/helpers/initpro-initpro-kassa-php-sdk/src/Client.php");
			include_once  (__DIR__."/helpers/initpro-initpro-kassa-php-sdk/src/GroupManager.php");

			$positions = $order->getItems();

			$payment = new Payment(Payment::TYPE_CARD, round((float)$order->getActualPrice(), 2));

			$payment_status = $order->getPaymentStatus();

			$method = ($payment_status == $this->tranz_config['object-prinyata']) ? Check::INTENT_SELL : Check::INTENT_SELL_RETURN;

			$customer_id = $order->getCustomerId();
			// $customer = customer::get($customer_id);
			$customer = customer::get();

			$uniqid = uniqid(strval($order->getNumber()), true);

			// покупатель зарегистрирован, тогда у него email хранится в поле 'e-mail'. Если не зарегистрирован, то email хранится в поле 'email' (без дефиса)
			$email = $customer->getValue('e-mail');

			if(empty($email)) {
				$email = $customer->getValue('email');
			}

			$check = new Check($uniqid, $email, $method, $sno);
			$check->setShouldPrint($is_print_check);
			$check->addPayment($payment);

			if ($vat) {
				if ($vat == 'zero') {
					$params['vat'] = 0;
				}
				$vat_object = new Vat($vat);
			}
			else{
				$vat_object = new Vat(0);
			}

			foreach( $positions as $position )
			{
				$positionObj = new Position($position->getName(),
												  floatval($position->getActualPrice()),
												  floatval($position->getAmount()),
												  floatval($position->getTotalActualPrice()),
												  floatval($position->getDiscountValue()),
												  $vat_object);
				$check->addPosition($positionObj);
			}

			$client = new Client($shop_id, $secret);

			if (!empty(@$host)){
				$client->setHost($host);
			}

			$manager = new GroupManager($client);
			$manager->registerGroup('default', $queue_id);
			$manager->setDefaultGroup('default');

			try {
				$response = $manager->putCheck($check);			
			} catch (SdkException $e) {
				$error = $e->getMessage();
				return false;
			}

			if (empty($error)){
				$sql = "INSERT INTO cms3_order_fiscalization_status (order_id, operation_id, status) VALUES (".$order->getNumber().", '$uniqid', 'pending');";
				$connection = ConnectionPool::getInstance()->getConnection();
				$result = $connection->queryResult($sql);
			}

			$config = [
				'host' => $host,
				'is_print_check' => $is_print_check,
				'queue_id' => $queue_id,
				'shop_id' => $shop_id,
				'secret' => $secret,
			];

			file_put_contents('initpro_config.json', json_encode($config));

			return true;
		}
	}